"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleModelPayload = void 0;
const typescript_1 = __importDefault(require("typescript"));
const replace_object_1 = require("../helpers/replace-object");
async function handleModelPayload(typeAlias, replacer, model, nsName) {
    const type = typeAlias.type;
    if (type.kind !== typescript_1.default.SyntaxKind.TypeLiteral) {
        throw new Error(`Provided object is not a type literal: ${type.getText()}`);
    }
    const scalarsField = type.members.find((m) => m.name?.getText() === 'scalars');
    if (scalarsField) {
        const object = scalarsField?.type
            ?.typeArguments?.[0];
        if (!object) {
            throw new Error(`Payload scalars could not be resolved: ${type.getText()}`);
        }
        (0, replace_object_1.replaceObject)(model, object, nsName, replacer, typeAlias.name.getText());
    }
    const objectsField = type.members.find((m) => m.name?.getText() === 'objects');
    // TODO: Implement objects field
    if (objectsField) {
        const members = objectsField?.type
            ?.members;
        if (members?.length) {
            console.log(`You had an object fields, but they aren't supported yet.\nCan you open a issue at https://github.com/arthurfiorette/prisma-json-types-generator?\n`, {
                model,
                typeAlias: typeAlias.getText()
            });
        }
    }
}
exports.handleModelPayload = handleModelPayload;
//# sourceMappingURL=model-payload.js.map